@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 12638 2020-12-17 07:19:51Z Lavender $
+# $Id: __init__.py 12658 2020-12-25 01:35:21Z Lavender $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2020-12-17 16:19:51 +0900 (週四, 17 十二月 2020) $
-# $Revision: 12638 $
+# $Date: 2020-12-25 10:35:21 +0900 (週五, 25 十二月 2020) $
+# $Revision: 12658 $
 
 # Avoid conflict with Iuno.cloud.logging moudle.
 from __future__ import absolute_import
@@ -27,6 +27,8 @@ import singletonmixin
 
 from Iuppiter.Logging import createLogger
 
+SERVICES = ('queue', 'mail', 'logging', 'browser', 'storage', 'metrics')
+
 class LocalCacheProvider(singletonmixin.Singleton):
     """
     Local cache provider which controls all cache access in local file storage.
@@ -113,9 +115,7 @@ class LocalCacheProvider(singletonmixin.Singleton):
 
 localCache = LocalCacheProvider.getInstance()
 
-def attachSettings(settingsLocals, services=(
-                    'queue', 'mail', 'logging', 
-                    'browser', 'storage', 'metrics'),
+def attachSettings(settingsLocals, services=SERVICES,
                    serviceSettings=None,
                    loggingFile=None, loggingLevel=None,
                    cache=False, cacheDir=None):
@@ -323,9 +323,7 @@ def tryGet(methodName, backends, preferred=None, *args, **kws):
             return HostInfo(backend, info)
     return None
 
-def attachURLs(settings, urlpatterns, services=(
-                    'queue', 'mail', 'logging', 
-                    'browser', 'storage', 'metrics')):
+def attachURLs(settings, urlpatterns, services=SERVICES):
                     
     for service in services:
         try:
