@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 12638 2020-12-17 07:19:51Z Lavender $
+# $Id: __init__.py 12658 2020-12-25 01:35:21Z Lavender $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2020-12-17 16:19:51 +0900 (週四, 17 十二月 2020) $
-# $Revision: 12638 $
+# $Date: 2020-12-25 10:35:21 +0900 (週五, 25 十二月 2020) $
+# $Revision: 12658 $
 
 import logging
 
@@ -253,13 +253,11 @@ def attachURLs(settings, urlpatterns):
 
     from django.views.decorators.csrf import csrf_exempt
     from django.conf.urls import url, include
-    from des import urls as des_urls
 
     from Iuno.cloud.logging.views import sendLog
     
     # logging
     urlpatterns += patterns('',
-        url(r'^django-des/', include(des_urls)),
         url(r'^log/', csrf_exempt(partial(sendLog,
             title=settings.APP_NAME if hasattr(settings, 'APP_NAME') else '')),
             name='sendLog'),
