@@ -1,8 +1,8 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: start_project.py 11920 2020-02-12 07:55:26Z Lavender $
+# $Id: start_project.py 12434 2020-07-29 19:01:27Z Lavender $
 #
-# Copyright (c) 2019 Nuwa Information Co., Ltd, All Rights Reserved.
+# Copyright (c) 2016 Nuwa Information Co., Ltd, All Rights Reserved.
 #
 # Licensed under the Proprietary License,
 # you may not use this file except in compliance with the License.
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2020-02-12 15:55:26 +0800 (週三, 12 二月 2020) $
-# $Revision: 11920 $
+# $Date: 2020-07-30 04:01:27 +0900 (週四, 30 七月 2020) $
+# $Revision: 12434 $
 
 import os
 import sys
@@ -263,8 +263,14 @@ class Command(BaseCommand):
         with open(urlPath, 'r') as url:
             content = url.read()
 
+        context = {
+            "name": name.lower(),
+            "version": IUNO_VERSION,
+            "pandora": pandora,
+        }
+        
         temp1 = get_template('scaffold/Urls.txt').render()
-        temp2 = get_template('scaffold/UrlsTemplate.txt').render()
+        temp2 = get_template('scaffold/UrlsTemplate.txt').render(context)
         content = content.replace(temp1, temp2)
 
         with open(urlPath, 'w') as url:
