@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 12555 2020-10-15 08:37:39Z Lavender $
+# $Id: __init__.py 12673 2021-01-06 05:40:40Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2020-10-15 17:37:39 +0900 (週四, 15 十月 2020) $
-# $Revision: 12555 $
+# $Date: 2021-01-06 14:40:40 +0900 (週三, 06 一月 2021) $
+# $Revision: 12673 $
 
 import os
 import re
@@ -122,6 +122,18 @@ CKEDITOR_CONFIGS = {
     }
 }
 
+NEED_SLUG_WORDS = ["+",]
+
+def slugifier(value, allow_unicode=False):
+    from oscar.core.utils import default_slugifier
+    slug = default_slugifier(value, allow_unicode=allow_unicode)
+    
+    for word in NEED_SLUG_WORDS:
+        slug = slug.replace(word, "_")
+        
+    return slug
+    
+
 def attachSettings(settingsDict, enablePaypal=False):
     """
     Attach default settings to settings.py.
@@ -338,8 +350,12 @@ def attachSettings(settingsDict, enablePaypal=False):
         update(settingsDict, ADD_STATICFILES_FINDERS)
 
     #=========================================================================
+    # oscar
     if 'OSCAR_DEFAULT_CURRENCY' not in settingsDict:
         settingsDict['OSCAR_DEFAULT_CURRENCY'] = 'USD'
+        
+    if 'OSCAR_SLUG_FUNCTION' not in settingsDict:
+        settingsDict['OSCAR_SLUG_FUNCTION'] = 'Iuno.shop.slugifier'
     #=========================================================================
     # Oscar default settings 
     # __import__ 模組的用法與官方文件有落差，可能是使用時帶入參數有誤，
@@ -1070,7 +1086,7 @@ def buildAPIForm(submission, request, apiName, extra={}):
 
 
         # modify return Url
-        ap.url_dict['ReturnURL'] = returnUrl
+        ap.url_dict['ReturnURL'] = "%s?return" % returnUrl
         ap.url_dict['OrderResultURL'] = returnUrl
         ap.url_dict['ClientBackURL'] = backUrl
 
