@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: views.py 12656 2020-12-24 06:28:00Z Lavender $
+# $Id: views.py 12678 2021-01-07 18:15:03Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2020-12-24 15:28:00 +0900 (週四, 24 十二月 2020) $
-# $Revision: 12656 $ 
+# $Date: 2021-01-08 03:15:03 +0900 (週五, 08 一月 2021) $
+# $Revision: 12678 $ 
 
 import json
 import logging
@@ -256,6 +256,10 @@ def placeOrder(self, basket, total,  # noqa (too complex (12))
         shipping_method, shipping_charge, user=user,
         shipping_address=shipping_address, billing_address=billing_address,
         order_number=order_number, status=status, request=request, **kwargs)
+    
+    # send mail
+    msg = "%s: %s" % (_("Order number"), order_number)
+    sendMessageToAdmin(_("Customer order notification"), msg)
    
     if user:
         if (user.is_authenticated and 
@@ -424,10 +428,10 @@ def sendOrderEmail(order, subjectTemp, htmlTemp, txtTemp, context={}):
     except Exception as e:
         logger.error("Error send order email: %s" % e)
         
-def sandMessageToAdmin(subject, message):
+def sendMessageToAdmin(subject, message):
     try:
-        if hasattr(settings, 'IUNO_SHOP_SAND_MAIL_ADMINS'):
-            emails = settings.IUNO_SHOP_SAND_MAIL_ADMINS
+        if hasattr(settings, 'IUNO_SHOP_SEND_MAIL_ADMINS'):
+            emails = settings.IUNO_SHOP_SEND_MAIL_ADMINS
         else:
             User = get_user_model()
             staff = User.objects.filter(Q(is_staff=True) | Q(is_superuser=True))
@@ -1135,9 +1139,15 @@ class SuccessResponseView2(_PaymentDetailsView):
         # apiName
         self.apiName = kwargs['name']
         
-        msg = "%s: %s" % (_('User'), request.user.username)
-        
-        sandMessageToAdmin(_("User checkout notification"), msg)
+        if hasattr(settings, "IUNO_SHOP_SEND_MAIL_WHEN_USER_PAID"):
+            if settings.IUNO_SHOP_SEND_MAIL_WHEN_USER_PAID:
+                data = ""
+                for k, v in request.POST.items():
+                    data += " %s: %s" % (k, v)
+                msg = "%s: %s\n%s: \n%s" % (
+                    _('User'), request.user.username, _("Data"), data)
+                
+                sendMessageToAdmin(_("User checkout notification"), msg)
         
         if not self.apiName in [
             SPGATEWAY, ALLPAY, ECPAY, CATHAYBK_CREDIT, 
@@ -1212,6 +1222,9 @@ class SuccessResponseView2(_PaymentDetailsView):
                         rtnMsg=self.rtnMsg,
                     )
                     allpayTrade.save()
+                    
+                if "return" in request.GET:
+                    return HttpResponse("1|OK")
             elif self.apiName == SPGATEWAY:
                 # data
                 data = json.loads(request.POST.get('JSONData', '{}'))
@@ -1812,7 +1825,7 @@ class ECPayServerReplyView(generic.View):
                     return HttpResponse("|ErrorMessage")
                 order.save()
                 
-                sandMessageToAdmin(
+                sendMessageToAdmin(
                     _("[%(site)s]Logistic order status change") % {
                         'site': siteName,
                     },
